"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class DnsManagedZoneXDnssecConfigXDefaultKeySpecs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALGORITHM_FIELD_NUMBER: builtins.int
    KEY_LENGTH_FIELD_NUMBER: builtins.int
    KEY_TYPE_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    algorithm: builtins.str
    key_length: builtins.float
    key_type: builtins.str
    kind: builtins.str
    def __init__(
        self,
        *,
        algorithm: builtins.str = ...,
        key_length: builtins.float = ...,
        key_type: builtins.str = ...,
        kind: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["algorithm", b"algorithm", "key_length", b"key_length", "key_type", b"key_type", "kind", b"kind"]) -> None: ...

global___DnsManagedZoneXDnssecConfigXDefaultKeySpecs = DnsManagedZoneXDnssecConfigXDefaultKeySpecs

@typing_extensions.final
class DnsManagedZoneXDnssecConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KIND_FIELD_NUMBER: builtins.int
    NON_EXISTENCE_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    DEFAULT_KEY_SPECS_FIELD_NUMBER: builtins.int
    kind: builtins.str
    non_existence: builtins.str
    state: builtins.str
    @property
    def default_key_specs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DnsManagedZoneXDnssecConfigXDefaultKeySpecs]: ...
    def __init__(
        self,
        *,
        kind: builtins.str = ...,
        non_existence: builtins.str = ...,
        state: builtins.str = ...,
        default_key_specs: collections.abc.Iterable[global___DnsManagedZoneXDnssecConfigXDefaultKeySpecs] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_key_specs", b"default_key_specs", "kind", b"kind", "non_existence", b"non_existence", "state", b"state"]) -> None: ...

global___DnsManagedZoneXDnssecConfig = DnsManagedZoneXDnssecConfig

@typing_extensions.final
class DnsManagedZoneXForwardingConfigXTargetNameServers(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FORWARDING_PATH_FIELD_NUMBER: builtins.int
    IPV4_ADDRESS_FIELD_NUMBER: builtins.int
    forwarding_path: builtins.str
    ipv4_address: builtins.str
    def __init__(
        self,
        *,
        forwarding_path: builtins.str = ...,
        ipv4_address: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["forwarding_path", b"forwarding_path", "ipv4_address", b"ipv4_address"]) -> None: ...

global___DnsManagedZoneXForwardingConfigXTargetNameServers = DnsManagedZoneXForwardingConfigXTargetNameServers

@typing_extensions.final
class DnsManagedZoneXForwardingConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TARGET_NAME_SERVERS_FIELD_NUMBER: builtins.int
    @property
    def target_name_servers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DnsManagedZoneXForwardingConfigXTargetNameServers]: ...
    def __init__(
        self,
        *,
        target_name_servers: collections.abc.Iterable[global___DnsManagedZoneXForwardingConfigXTargetNameServers] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["target_name_servers", b"target_name_servers"]) -> None: ...

global___DnsManagedZoneXForwardingConfig = DnsManagedZoneXForwardingConfig

@typing_extensions.final
class DnsManagedZoneXPeeringConfigXTargetNetwork(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NETWORK_URL_FIELD_NUMBER: builtins.int
    network_url: builtins.str
    def __init__(
        self,
        *,
        network_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["network_url", b"network_url"]) -> None: ...

global___DnsManagedZoneXPeeringConfigXTargetNetwork = DnsManagedZoneXPeeringConfigXTargetNetwork

@typing_extensions.final
class DnsManagedZoneXPeeringConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TARGET_NETWORK_FIELD_NUMBER: builtins.int
    @property
    def target_network(self) -> global___DnsManagedZoneXPeeringConfigXTargetNetwork: ...
    def __init__(
        self,
        *,
        target_network: global___DnsManagedZoneXPeeringConfigXTargetNetwork | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["target_network", b"target_network"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["target_network", b"target_network"]) -> None: ...

global___DnsManagedZoneXPeeringConfig = DnsManagedZoneXPeeringConfig

@typing_extensions.final
class DnsManagedZoneXPrivateVisibilityConfigXNetworks(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NETWORK_URL_FIELD_NUMBER: builtins.int
    network_url: builtins.str
    def __init__(
        self,
        *,
        network_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["network_url", b"network_url"]) -> None: ...

global___DnsManagedZoneXPrivateVisibilityConfigXNetworks = DnsManagedZoneXPrivateVisibilityConfigXNetworks

@typing_extensions.final
class DnsManagedZoneXPrivateVisibilityConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NETWORKS_FIELD_NUMBER: builtins.int
    @property
    def networks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DnsManagedZoneXPrivateVisibilityConfigXNetworks]: ...
    def __init__(
        self,
        *,
        networks: collections.abc.Iterable[global___DnsManagedZoneXPrivateVisibilityConfigXNetworks] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["networks", b"networks"]) -> None: ...

global___DnsManagedZoneXPrivateVisibilityConfig = DnsManagedZoneXPrivateVisibilityConfig

@typing_extensions.final
class DnsManagedZoneXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___DnsManagedZoneXTimeouts = DnsManagedZoneXTimeouts

@typing_extensions.final
class DnsManagedZone(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CREATION_TIME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DNS_NAME_FIELD_NUMBER: builtins.int
    FORCE_DESTROY_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    MANAGED_ZONE_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NAME_SERVERS_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    VISIBILITY_FIELD_NUMBER: builtins.int
    DNSSEC_CONFIG_FIELD_NUMBER: builtins.int
    FORWARDING_CONFIG_FIELD_NUMBER: builtins.int
    PEERING_CONFIG_FIELD_NUMBER: builtins.int
    PRIVATE_VISIBILITY_CONFIG_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    creation_time: builtins.str
    description: builtins.str
    dns_name: builtins.str
    force_destroy: builtins.bool
    id: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    managed_zone_id: builtins.float
    name: builtins.str
    @property
    def name_servers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    project: builtins.str
    visibility: builtins.str
    @property
    def dnssec_config(self) -> global___DnsManagedZoneXDnssecConfig: ...
    @property
    def forwarding_config(self) -> global___DnsManagedZoneXForwardingConfig: ...
    @property
    def peering_config(self) -> global___DnsManagedZoneXPeeringConfig: ...
    @property
    def private_visibility_config(self) -> global___DnsManagedZoneXPrivateVisibilityConfig: ...
    @property
    def timeouts(self) -> global___DnsManagedZoneXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        creation_time: builtins.str = ...,
        description: builtins.str = ...,
        dns_name: builtins.str = ...,
        force_destroy: builtins.bool = ...,
        id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        managed_zone_id: builtins.float = ...,
        name: builtins.str = ...,
        name_servers: collections.abc.Iterable[builtins.str] | None = ...,
        project: builtins.str = ...,
        visibility: builtins.str = ...,
        dnssec_config: global___DnsManagedZoneXDnssecConfig | None = ...,
        forwarding_config: global___DnsManagedZoneXForwardingConfig | None = ...,
        peering_config: global___DnsManagedZoneXPeeringConfig | None = ...,
        private_visibility_config: global___DnsManagedZoneXPrivateVisibilityConfig | None = ...,
        timeouts: global___DnsManagedZoneXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dnssec_config", b"dnssec_config", "forwarding_config", b"forwarding_config", "peering_config", b"peering_config", "private_visibility_config", b"private_visibility_config", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["creation_time", b"creation_time", "description", b"description", "dns_name", b"dns_name", "dnssec_config", b"dnssec_config", "force_destroy", b"force_destroy", "forwarding_config", b"forwarding_config", "id", b"id", "labels", b"labels", "managed_zone_id", b"managed_zone_id", "name", b"name", "name_servers", b"name_servers", "peering_config", b"peering_config", "private_visibility_config", b"private_visibility_config", "project", b"project", "resource_info", b"resource_info", "timeouts", b"timeouts", "visibility", b"visibility"]) -> None: ...

global___DnsManagedZone = DnsManagedZone

@typing_extensions.final
class DnsPolicyXAlternativeNameServerConfigXTargetNameServers(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FORWARDING_PATH_FIELD_NUMBER: builtins.int
    IPV4_ADDRESS_FIELD_NUMBER: builtins.int
    forwarding_path: builtins.str
    ipv4_address: builtins.str
    def __init__(
        self,
        *,
        forwarding_path: builtins.str = ...,
        ipv4_address: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["forwarding_path", b"forwarding_path", "ipv4_address", b"ipv4_address"]) -> None: ...

global___DnsPolicyXAlternativeNameServerConfigXTargetNameServers = DnsPolicyXAlternativeNameServerConfigXTargetNameServers

@typing_extensions.final
class DnsPolicyXAlternativeNameServerConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TARGET_NAME_SERVERS_FIELD_NUMBER: builtins.int
    @property
    def target_name_servers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DnsPolicyXAlternativeNameServerConfigXTargetNameServers]: ...
    def __init__(
        self,
        *,
        target_name_servers: collections.abc.Iterable[global___DnsPolicyXAlternativeNameServerConfigXTargetNameServers] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["target_name_servers", b"target_name_servers"]) -> None: ...

global___DnsPolicyXAlternativeNameServerConfig = DnsPolicyXAlternativeNameServerConfig

@typing_extensions.final
class DnsPolicyXNetworks(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NETWORK_URL_FIELD_NUMBER: builtins.int
    network_url: builtins.str
    def __init__(
        self,
        *,
        network_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["network_url", b"network_url"]) -> None: ...

global___DnsPolicyXNetworks = DnsPolicyXNetworks

@typing_extensions.final
class DnsPolicyXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___DnsPolicyXTimeouts = DnsPolicyXTimeouts

@typing_extensions.final
class DnsPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    ENABLE_INBOUND_FORWARDING_FIELD_NUMBER: builtins.int
    ENABLE_LOGGING_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ALTERNATIVE_NAME_SERVER_CONFIG_FIELD_NUMBER: builtins.int
    NETWORKS_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    description: builtins.str
    enable_inbound_forwarding: builtins.bool
    enable_logging: builtins.bool
    id: builtins.str
    name: builtins.str
    project: builtins.str
    @property
    def alternative_name_server_config(self) -> global___DnsPolicyXAlternativeNameServerConfig: ...
    @property
    def networks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DnsPolicyXNetworks]: ...
    @property
    def timeouts(self) -> global___DnsPolicyXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        enable_inbound_forwarding: builtins.bool = ...,
        enable_logging: builtins.bool = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        alternative_name_server_config: global___DnsPolicyXAlternativeNameServerConfig | None = ...,
        networks: collections.abc.Iterable[global___DnsPolicyXNetworks] | None = ...,
        timeouts: global___DnsPolicyXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["alternative_name_server_config", b"alternative_name_server_config", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["alternative_name_server_config", b"alternative_name_server_config", "description", b"description", "enable_inbound_forwarding", b"enable_inbound_forwarding", "enable_logging", b"enable_logging", "id", b"id", "name", b"name", "networks", b"networks", "project", b"project", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___DnsPolicy = DnsPolicy

@typing_extensions.final
class DnsRecordSetXRoutingPolicyXGeo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOCATION_FIELD_NUMBER: builtins.int
    RRDATAS_FIELD_NUMBER: builtins.int
    location: builtins.str
    @property
    def rrdatas(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        location: builtins.str = ...,
        rrdatas: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["location", b"location", "rrdatas", b"rrdatas"]) -> None: ...

global___DnsRecordSetXRoutingPolicyXGeo = DnsRecordSetXRoutingPolicyXGeo

@typing_extensions.final
class DnsRecordSetXRoutingPolicyXWrr(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RRDATAS_FIELD_NUMBER: builtins.int
    WEIGHT_FIELD_NUMBER: builtins.int
    @property
    def rrdatas(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    weight: builtins.float
    def __init__(
        self,
        *,
        rrdatas: collections.abc.Iterable[builtins.str] | None = ...,
        weight: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["rrdatas", b"rrdatas", "weight", b"weight"]) -> None: ...

global___DnsRecordSetXRoutingPolicyXWrr = DnsRecordSetXRoutingPolicyXWrr

@typing_extensions.final
class DnsRecordSetXRoutingPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GEO_FIELD_NUMBER: builtins.int
    WRR_FIELD_NUMBER: builtins.int
    @property
    def geo(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DnsRecordSetXRoutingPolicyXGeo]: ...
    @property
    def wrr(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DnsRecordSetXRoutingPolicyXWrr]: ...
    def __init__(
        self,
        *,
        geo: collections.abc.Iterable[global___DnsRecordSetXRoutingPolicyXGeo] | None = ...,
        wrr: collections.abc.Iterable[global___DnsRecordSetXRoutingPolicyXWrr] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["geo", b"geo", "wrr", b"wrr"]) -> None: ...

global___DnsRecordSetXRoutingPolicy = DnsRecordSetXRoutingPolicy

@typing_extensions.final
class DnsRecordSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    MANAGED_ZONE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    RRDATAS_FIELD_NUMBER: builtins.int
    TTL_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    ROUTING_POLICY_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    id: builtins.str
    managed_zone: builtins.str
    name: builtins.str
    project: builtins.str
    @property
    def rrdatas(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    ttl: builtins.float
    type: builtins.str
    @property
    def routing_policy(self) -> global___DnsRecordSetXRoutingPolicy: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        managed_zone: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        rrdatas: collections.abc.Iterable[builtins.str] | None = ...,
        ttl: builtins.float = ...,
        type: builtins.str = ...,
        routing_policy: global___DnsRecordSetXRoutingPolicy | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "routing_policy", b"routing_policy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "managed_zone", b"managed_zone", "name", b"name", "project", b"project", "resource_info", b"resource_info", "routing_policy", b"routing_policy", "rrdatas", b"rrdatas", "ttl", b"ttl", "type", b"type"]) -> None: ...

global___DnsRecordSet = DnsRecordSet



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_eks.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x61ws/aws_eks.proto\x12\x13oak9.tython.aws.eks\x1a\x13shared/shared.proto\"[\n\x0f\x43lusterProvider\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07key_arn\x18\x02 \x01(\t\"\x9d\x01\n\x17\x43lusterEncryptionConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tresources\x18\x02 \x03(\t\x12\x36\n\x08provider\x18\x03 \x01(\x0b\x32$.oak9.tython.aws.eks.ClusterProvider\"\xe2\x01\n\x19\x43lusterResourcesVpcConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12security_group_ids\x18\x02 \x03(\t\x12\x12\n\nsubnet_ids\x18\x03 \x03(\t\x12\x1b\n\x13public_access_cidrs\x18\x04 \x03(\t\x12\x1f\n\x17\x65ndpoint_private_access\x18\x05 \x01(\x08\x12\x1e\n\x16\x65ndpoint_public_access\x18\x06 \x01(\x08\"t\n\x1e\x43lusterKubernetesNetworkConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11service_ipv4_cidr\x18\x02 \x01(\t\"\xe2\x02\n\x07\x43luster\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07version\x18\x02 \x01(\t\x12G\n\x11\x65ncryption_config\x18\x03 \x03(\x0b\x32,.oak9.tython.aws.eks.ClusterEncryptionConfig\x12\x10\n\x08role_arn\x18\x04 \x01(\t\x12L\n\x14resources_vpc_config\x18\x05 \x01(\x0b\x32..oak9.tython.aws.eks.ClusterResourcesVpcConfig\x12V\n\x19kubernetes_network_config\x18\x06 \x01(\x0b\x32\x33.oak9.tython.aws.eks.ClusterKubernetesNetworkConfig\x12\x0c\n\x04name\x18\x07 \x01(\t\"\xa5\x01\n\x03\x45KS\x12-\n\x07\x63luster\x18\x01 \x01(\x0b\x32\x1c.oak9.tython.aws.eks.Cluster\x12<\n\x0f\x66\x61rgate_profile\x18\x02 \x03(\x0b\x32#.oak9.tython.aws.eks.FargateProfile\x12\x31\n\tnodegroup\x18\x03 \x03(\x0b\x32\x1e.oak9.tython.aws.eks.Nodegroup\"j\n\x13\x46\x61rgateProfileLabel\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\x9e\x01\n\x16\x46\x61rgateProfileSelector\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tnamespace\x18\x02 \x01(\t\x12\x38\n\x06labels\x18\x03 \x03(\x0b\x32(.oak9.tython.aws.eks.FargateProfileLabel\"\xd8\x02\n\x0e\x46\x61rgateProfile\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0c\x63luster_name\x18\x02 \x01(\t\x12\x1c\n\x14\x66\x61rgate_profile_name\x18\x03 \x01(\t\x12\x1e\n\x16pod_execution_role_arn\x18\x04 \x01(\t\x12\x0f\n\x07subnets\x18\x05 \x03(\t\x12>\n\tselectors\x18\x06 \x03(\x0b\x32+.oak9.tython.aws.eks.FargateProfileSelector\x12;\n\x04tags\x18\x07 \x03(\x0b\x32-.oak9.tython.aws.eks.FargateProfile.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8b\x01\n\x16NodegroupScalingConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08min_size\x18\x02 \x01(\x01\x12\x14\n\x0c\x64\x65sired_size\x18\x03 \x01(\x01\x12\x10\n\x08max_size\x18\x04 \x01(\x01\"\x8a\x01\n$NodegroupLaunchTemplateSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\"\x85\x01\n\x15NodegroupRemoteAccess\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1e\n\x16source_security_groups\x18\x02 \x03(\t\x12\x13\n\x0b\x65\x63\x32_ssh_key\x18\x03 \x01(\t\"\xc7\x05\n\tNodegroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x43\n\x0escaling_config\x18\x02 \x01(\x0b\x32+.oak9.tython.aws.eks.NodegroupScalingConfig\x12:\n\x06labels\x18\x03 \x03(\x0b\x32*.oak9.tython.aws.eks.Nodegroup.LabelsEntry\x12\x17\n\x0frelease_version\x18\x04 \x01(\t\x12\x16\n\x0enodegroup_name\x18\x05 \x01(\t\x12\x0f\n\x07subnets\x18\x06 \x03(\t\x12\x11\n\tnode_role\x18\x07 \x01(\t\x12\x10\n\x08\x61mi_type\x18\x08 \x01(\t\x12\x1c\n\x14\x66orce_update_enabled\x18\t \x01(\x08\x12\x0f\n\x07version\x18\n \x01(\t\x12R\n\x0flaunch_template\x18\x0b \x01(\x0b\x32\x39.oak9.tython.aws.eks.NodegroupLaunchTemplateSpecification\x12\x41\n\rremote_access\x18\x0c \x01(\x0b\x32*.oak9.tython.aws.eks.NodegroupRemoteAccess\x12\x11\n\tdisk_size\x18\r \x01(\x01\x12\x14\n\x0c\x63luster_name\x18\x0e \x01(\t\x12\x16\n\x0einstance_types\x18\x0f \x03(\t\x12\x36\n\x04tags\x18\x10 \x03(\x0b\x32(.oak9.tython.aws.eks.Nodegroup.TagsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_eks_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _FARGATEPROFILE_TAGSENTRY._options = None
  _FARGATEPROFILE_TAGSENTRY._serialized_options = b'8\001'
  _NODEGROUP_LABELSENTRY._options = None
  _NODEGROUP_LABELSENTRY._serialized_options = b'8\001'
  _NODEGROUP_TAGSENTRY._options = None
  _NODEGROUP_TAGSENTRY._serialized_options = b'8\001'
  _CLUSTERPROVIDER._serialized_start=63
  _CLUSTERPROVIDER._serialized_end=154
  _CLUSTERENCRYPTIONCONFIG._serialized_start=157
  _CLUSTERENCRYPTIONCONFIG._serialized_end=314
  _CLUSTERRESOURCESVPCCONFIG._serialized_start=317
  _CLUSTERRESOURCESVPCCONFIG._serialized_end=543
  _CLUSTERKUBERNETESNETWORKCONFIG._serialized_start=545
  _CLUSTERKUBERNETESNETWORKCONFIG._serialized_end=661
  _CLUSTER._serialized_start=664
  _CLUSTER._serialized_end=1018
  _EKS._serialized_start=1021
  _EKS._serialized_end=1186
  _FARGATEPROFILELABEL._serialized_start=1188
  _FARGATEPROFILELABEL._serialized_end=1294
  _FARGATEPROFILESELECTOR._serialized_start=1297
  _FARGATEPROFILESELECTOR._serialized_end=1455
  _FARGATEPROFILE._serialized_start=1458
  _FARGATEPROFILE._serialized_end=1802
  _FARGATEPROFILE_TAGSENTRY._serialized_start=1759
  _FARGATEPROFILE_TAGSENTRY._serialized_end=1802
  _NODEGROUPSCALINGCONFIG._serialized_start=1805
  _NODEGROUPSCALINGCONFIG._serialized_end=1944
  _NODEGROUPLAUNCHTEMPLATESPECIFICATION._serialized_start=1947
  _NODEGROUPLAUNCHTEMPLATESPECIFICATION._serialized_end=2085
  _NODEGROUPREMOTEACCESS._serialized_start=2088
  _NODEGROUPREMOTEACCESS._serialized_end=2221
  _NODEGROUP._serialized_start=2224
  _NODEGROUP._serialized_end=2935
  _NODEGROUP_LABELSENTRY._serialized_start=2845
  _NODEGROUP_LABELSENTRY._serialized_end=2890
  _NODEGROUP_TAGSENTRY._serialized_start=1759
  _NODEGROUP_TAGSENTRY._serialized_end=1802
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_kinesisanalytics.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x61ws/aws_kinesisanalytics.proto\x12 oak9.tython.aws.kinesisanalytics\x1a\x13shared/shared.proto\"\x83\x01\n\x17\x41pplicationRecordColumn\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07mapping\x18\x02 \x01(\t\x12\x10\n\x08sql_type\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\"t\n ApplicationJSONMappingParameters\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0frecord_row_path\x18\x02 \x01(\t\"\x99\x01\n\x1f\x41pplicationCSVMappingParameters\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1c\n\x14record_row_delimiter\x18\x02 \x01(\t\x12\x1f\n\x17record_column_delimiter\x18\x03 \x01(\t\"\xa0\x02\n\x1c\x41pplicationMappingParameters\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x63\n\x17json_mapping_parameters\x18\x02 \x01(\x0b\x32\x42.oak9.tython.aws.kinesisanalytics.ApplicationJSONMappingParameters\x12\x62\n\x17\x63s_v_mapping_parameters\x18\x03 \x01(\x0b\x32\x41.oak9.tython.aws.kinesisanalytics.ApplicationCSVMappingParameters\"\xca\x01\n\x17\x41pplicationRecordFormat\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12Z\n\x12mapping_parameters\x18\x02 \x01(\x0b\x32>.oak9.tython.aws.kinesisanalytics.ApplicationMappingParameters\x12\x1a\n\x12record_format_type\x18\x03 \x01(\t\"\x8f\x02\n\x16\x41pplicationInputSchema\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0frecord_encoding\x18\x02 \x01(\t\x12Q\n\x0erecord_columns\x18\x03 \x03(\x0b\x32\x39.oak9.tython.aws.kinesisanalytics.ApplicationRecordColumn\x12P\n\rrecord_format\x18\x04 \x01(\x0b\x32\x39.oak9.tython.aws.kinesisanalytics.ApplicationRecordFormat\"\x81\x01\n\x1e\x41pplicationKinesisStreamsInput\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cresource_arn\x18\x02 \x01(\t\x12\x10\n\x08role_arn\x18\x03 \x01(\t\"\x82\x01\n\x1f\x41pplicationKinesisFirehoseInput\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cresource_arn\x18\x02 \x01(\t\x12\x10\n\x08role_arn\x18\x03 \x01(\t\"\x82\x01\n\x1f\x41pplicationInputLambdaProcessor\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cresource_arn\x18\x02 \x01(\t\x12\x10\n\x08role_arn\x18\x03 \x01(\t\"\xc5\x01\n\'ApplicationInputProcessingConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x61\n\x16input_lambda_processor\x18\x02 \x01(\x0b\x32\x41.oak9.tython.aws.kinesisanalytics.ApplicationInputLambdaProcessor\"e\n\x1b\x41pplicationInputParallelism\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05\x63ount\x18\x02 \x01(\x05\"\xc1\x04\n\x10\x41pplicationInput\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bname_prefix\x18\x02 \x01(\t\x12N\n\x0cinput_schema\x18\x03 \x01(\x0b\x32\x38.oak9.tython.aws.kinesisanalytics.ApplicationInputSchema\x12_\n\x15kinesis_streams_input\x18\x04 \x01(\x0b\x32@.oak9.tython.aws.kinesisanalytics.ApplicationKinesisStreamsInput\x12\x61\n\x16kinesis_firehose_input\x18\x05 \x01(\x0b\x32\x41.oak9.tython.aws.kinesisanalytics.ApplicationKinesisFirehoseInput\x12q\n\x1einput_processing_configuration\x18\x06 \x01(\x0b\x32I.oak9.tython.aws.kinesisanalytics.ApplicationInputProcessingConfiguration\x12X\n\x11input_parallelism\x18\x07 \x01(\x0b\x32=.oak9.tython.aws.kinesisanalytics.ApplicationInputParallelism\"\xdf\x01\n\x0b\x41pplication\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x61pplication_name\x18\x02 \x01(\t\x12\x42\n\x06inputs\x18\x03 \x03(\x0b\x32\x32.oak9.tython.aws.kinesisanalytics.ApplicationInput\x12\x1f\n\x17\x61pplication_description\x18\x04 \x01(\t\x12\x18\n\x10\x61pplication_code\x18\x05 \x01(\t\"\x94\x02\n\x10KinesisAnalytics\x12\x42\n\x0b\x61pplication\x18\x01 \x03(\x0b\x32-.oak9.tython.aws.kinesisanalytics.Application\x12O\n\x12\x61pplication_output\x18\x02 \x03(\x0b\x32\x33.oak9.tython.aws.kinesisanalytics.ApplicationOutput\x12k\n!application_reference_data_source\x18\x03 \x03(\x0b\x32@.oak9.tython.aws.kinesisanalytics.ApplicationReferenceDataSource\"y\n\"ApplicationOutputDestinationSchema\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12record_format_type\x18\x02 \x01(\t\"\x80\x01\n\x1d\x41pplicationOutputLambdaOutput\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cresource_arn\x18\x02 \x01(\t\x12\x10\n\x08role_arn\x18\x03 \x01(\t\"\x89\x01\n&ApplicationOutputKinesisFirehoseOutput\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cresource_arn\x18\x02 \x01(\t\x12\x10\n\x08role_arn\x18\x03 \x01(\t\"\x88\x01\n%ApplicationOutputKinesisStreamsOutput\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cresource_arn\x18\x02 \x01(\t\x12\x10\n\x08role_arn\x18\x03 \x01(\t\"\xee\x03\n\x17\x41pplicationOutputOutput\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12`\n\x12\x64\x65stination_schema\x18\x02 \x01(\x0b\x32\x44.oak9.tython.aws.kinesisanalytics.ApplicationOutputDestinationSchema\x12V\n\rlambda_output\x18\x03 \x01(\x0b\x32?.oak9.tython.aws.kinesisanalytics.ApplicationOutputLambdaOutput\x12i\n\x17kinesis_firehose_output\x18\x04 \x01(\x0b\x32H.oak9.tython.aws.kinesisanalytics.ApplicationOutputKinesisFirehoseOutput\x12g\n\x16kinesis_streams_output\x18\x05 \x01(\x0b\x32G.oak9.tython.aws.kinesisanalytics.ApplicationOutputKinesisStreamsOutput\x12\x0c\n\x04name\x18\x06 \x01(\t\"\xb1\x01\n\x11\x41pplicationOutput\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x61pplication_name\x18\x02 \x01(\t\x12I\n\x06output\x18\x03 \x01(\x0b\x32\x39.oak9.tython.aws.kinesisanalytics.ApplicationOutputOutput\"\x96\x01\n*ApplicationReferenceDataSourceRecordColumn\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07mapping\x18\x02 \x01(\t\x12\x10\n\x08sql_type\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\"\x87\x01\n3ApplicationReferenceDataSourceJSONMappingParameters\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0frecord_row_path\x18\x02 \x01(\t\"\xac\x01\n2ApplicationReferenceDataSourceCSVMappingParameters\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1c\n\x14record_row_delimiter\x18\x02 \x01(\t\x12\x1f\n\x17record_column_delimiter\x18\x03 \x01(\t\"\xd9\x02\n/ApplicationReferenceDataSourceMappingParameters\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12v\n\x17json_mapping_parameters\x18\x02 \x01(\x0b\x32U.oak9.tython.aws.kinesisanalytics.ApplicationReferenceDataSourceJSONMappingParameters\x12u\n\x17\x63s_v_mapping_parameters\x18\x03 \x01(\x0b\x32T.oak9.tython.aws.kinesisanalytics.ApplicationReferenceDataSourceCSVMappingParameters\"\xf0\x01\n*ApplicationReferenceDataSourceRecordFormat\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12m\n\x12mapping_parameters\x18\x02 \x01(\x0b\x32Q.oak9.tython.aws.kinesisanalytics.ApplicationReferenceDataSourceMappingParameters\x12\x1a\n\x12record_format_type\x18\x03 \x01(\t\"\xcc\x02\n-ApplicationReferenceDataSourceReferenceSchema\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0frecord_encoding\x18\x02 \x01(\t\x12\x64\n\x0erecord_columns\x18\x03 \x03(\x0b\x32L.oak9.tython.aws.kinesisanalytics.ApplicationReferenceDataSourceRecordColumn\x12\x63\n\rrecord_format\x18\x04 \x01(\x0b\x32L.oak9.tython.aws.kinesisanalytics.ApplicationReferenceDataSourceRecordFormat\"\xb0\x01\n3ApplicationReferenceDataSourceS3ReferenceDataSource\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nbucket_arn\x18\x02 \x01(\t\x12\x10\n\x08\x66ile_key\x18\x03 \x01(\t\x12\x1a\n\x12reference_role_arn\x18\x04 \x01(\t\"\xe4\x02\n1ApplicationReferenceDataSourceReferenceDataSource\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12i\n\x10reference_schema\x18\x02 \x01(\x0b\x32O.oak9.tython.aws.kinesisanalytics.ApplicationReferenceDataSourceReferenceSchema\x12\x12\n\ntable_name\x18\x03 \x01(\t\x12w\n\x18s3_reference_data_source\x18\x04 \x01(\x0b\x32U.oak9.tython.aws.kinesisanalytics.ApplicationReferenceDataSourceS3ReferenceDataSource\"\xe7\x01\n\x1e\x41pplicationReferenceDataSource\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x61pplication_name\x18\x02 \x01(\t\x12r\n\x15reference_data_source\x18\x03 \x01(\x0b\x32S.oak9.tython.aws.kinesisanalytics.ApplicationReferenceDataSourceReferenceDataSourceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_kinesisanalytics_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _APPLICATIONRECORDCOLUMN._serialized_start=90
  _APPLICATIONRECORDCOLUMN._serialized_end=221
  _APPLICATIONJSONMAPPINGPARAMETERS._serialized_start=223
  _APPLICATIONJSONMAPPINGPARAMETERS._serialized_end=339
  _APPLICATIONCSVMAPPINGPARAMETERS._serialized_start=342
  _APPLICATIONCSVMAPPINGPARAMETERS._serialized_end=495
  _APPLICATIONMAPPINGPARAMETERS._serialized_start=498
  _APPLICATIONMAPPINGPARAMETERS._serialized_end=786
  _APPLICATIONRECORDFORMAT._serialized_start=789
  _APPLICATIONRECORDFORMAT._serialized_end=991
  _APPLICATIONINPUTSCHEMA._serialized_start=994
  _APPLICATIONINPUTSCHEMA._serialized_end=1265
  _APPLICATIONKINESISSTREAMSINPUT._serialized_start=1268
  _APPLICATIONKINESISSTREAMSINPUT._serialized_end=1397
  _APPLICATIONKINESISFIREHOSEINPUT._serialized_start=1400
  _APPLICATIONKINESISFIREHOSEINPUT._serialized_end=1530
  _APPLICATIONINPUTLAMBDAPROCESSOR._serialized_start=1533
  _APPLICATIONINPUTLAMBDAPROCESSOR._serialized_end=1663
  _APPLICATIONINPUTPROCESSINGCONFIGURATION._serialized_start=1666
  _APPLICATIONINPUTPROCESSINGCONFIGURATION._serialized_end=1863
  _APPLICATIONINPUTPARALLELISM._serialized_start=1865
  _APPLICATIONINPUTPARALLELISM._serialized_end=1966
  _APPLICATIONINPUT._serialized_start=1969
  _APPLICATIONINPUT._serialized_end=2546
  _APPLICATION._serialized_start=2549
  _APPLICATION._serialized_end=2772
  _KINESISANALYTICS._serialized_start=2775
  _KINESISANALYTICS._serialized_end=3051
  _APPLICATIONOUTPUTDESTINATIONSCHEMA._serialized_start=3053
  _APPLICATIONOUTPUTDESTINATIONSCHEMA._serialized_end=3174
  _APPLICATIONOUTPUTLAMBDAOUTPUT._serialized_start=3177
  _APPLICATIONOUTPUTLAMBDAOUTPUT._serialized_end=3305
  _APPLICATIONOUTPUTKINESISFIREHOSEOUTPUT._serialized_start=3308
  _APPLICATIONOUTPUTKINESISFIREHOSEOUTPUT._serialized_end=3445
  _APPLICATIONOUTPUTKINESISSTREAMSOUTPUT._serialized_start=3448
  _APPLICATIONOUTPUTKINESISSTREAMSOUTPUT._serialized_end=3584
  _APPLICATIONOUTPUTOUTPUT._serialized_start=3587
  _APPLICATIONOUTPUTOUTPUT._serialized_end=4081
  _APPLICATIONOUTPUT._serialized_start=4084
  _APPLICATIONOUTPUT._serialized_end=4261
  _APPLICATIONREFERENCEDATASOURCERECORDCOLUMN._serialized_start=4264
  _APPLICATIONREFERENCEDATASOURCERECORDCOLUMN._serialized_end=4414
  _APPLICATIONREFERENCEDATASOURCEJSONMAPPINGPARAMETERS._serialized_start=4417
  _APPLICATIONREFERENCEDATASOURCEJSONMAPPINGPARAMETERS._serialized_end=4552
  _APPLICATIONREFERENCEDATASOURCECSVMAPPINGPARAMETERS._serialized_start=4555
  _APPLICATIONREFERENCEDATASOURCECSVMAPPINGPARAMETERS._serialized_end=4727
  _APPLICATIONREFERENCEDATASOURCEMAPPINGPARAMETERS._serialized_start=4730
  _APPLICATIONREFERENCEDATASOURCEMAPPINGPARAMETERS._serialized_end=5075
  _APPLICATIONREFERENCEDATASOURCERECORDFORMAT._serialized_start=5078
  _APPLICATIONREFERENCEDATASOURCERECORDFORMAT._serialized_end=5318
  _APPLICATIONREFERENCEDATASOURCEREFERENCESCHEMA._serialized_start=5321
  _APPLICATIONREFERENCEDATASOURCEREFERENCESCHEMA._serialized_end=5653
  _APPLICATIONREFERENCEDATASOURCES3REFERENCEDATASOURCE._serialized_start=5656
  _APPLICATIONREFERENCEDATASOURCES3REFERENCEDATASOURCE._serialized_end=5832
  _APPLICATIONREFERENCEDATASOURCEREFERENCEDATASOURCE._serialized_start=5835
  _APPLICATIONREFERENCEDATASOURCEREFERENCEDATASOURCE._serialized_end=6191
  _APPLICATIONREFERENCEDATASOURCE._serialized_start=6194
  _APPLICATIONREFERENCEDATASOURCE._serialized_end=6425
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ClusterLoggingProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    BUCKET_NAME_FIELD_NUMBER: builtins.int
    S3_KEY_PREFIX_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    bucket_name: builtins.str
    s3_key_prefix: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        bucket_name: builtins.str = ...,
        s3_key_prefix: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket_name", b"bucket_name", "resource_info", b"resource_info", "s3_key_prefix", b"s3_key_prefix"]) -> None: ...

global___ClusterLoggingProperties = ClusterLoggingProperties

@typing_extensions.final
class Cluster(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ALLOW_VERSION_UPGRADE_FIELD_NUMBER: builtins.int
    AUTOMATED_SNAPSHOT_RETENTION_PERIOD_FIELD_NUMBER: builtins.int
    AVAILABILITY_ZONE_FIELD_NUMBER: builtins.int
    CLUSTER_IDENTIFIER_FIELD_NUMBER: builtins.int
    CLUSTER_PARAMETER_GROUP_NAME_FIELD_NUMBER: builtins.int
    CLUSTER_SECURITY_GROUPS_FIELD_NUMBER: builtins.int
    CLUSTER_SUBNET_GROUP_NAME_FIELD_NUMBER: builtins.int
    CLUSTER_TYPE_FIELD_NUMBER: builtins.int
    CLUSTER_VERSION_FIELD_NUMBER: builtins.int
    DB_NAME_FIELD_NUMBER: builtins.int
    ELASTIC_IP_FIELD_NUMBER: builtins.int
    ENCRYPTED_FIELD_NUMBER: builtins.int
    HSM_CLIENT_CERTIFICATE_IDENTIFIER_FIELD_NUMBER: builtins.int
    HSM_CONFIGURATION_IDENTIFIER_FIELD_NUMBER: builtins.int
    IAM_ROLES_FIELD_NUMBER: builtins.int
    KMS_KEY_ID_FIELD_NUMBER: builtins.int
    LOGGING_PROPERTIES_FIELD_NUMBER: builtins.int
    MASTER_USER_PASSWORD_FIELD_NUMBER: builtins.int
    MASTER_USERNAME_FIELD_NUMBER: builtins.int
    NODE_TYPE_FIELD_NUMBER: builtins.int
    NUMBER_OF_NODES_FIELD_NUMBER: builtins.int
    OWNER_ACCOUNT_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    PREFERRED_MAINTENANCE_WINDOW_FIELD_NUMBER: builtins.int
    PUBLICLY_ACCESSIBLE_FIELD_NUMBER: builtins.int
    SNAPSHOT_CLUSTER_IDENTIFIER_FIELD_NUMBER: builtins.int
    SNAPSHOT_IDENTIFIER_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    VPC_SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    allow_version_upgrade: builtins.bool
    automated_snapshot_retention_period: builtins.int
    availability_zone: builtins.str
    cluster_identifier: builtins.str
    cluster_parameter_group_name: builtins.str
    @property
    def cluster_security_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    cluster_subnet_group_name: builtins.str
    cluster_type: builtins.str
    cluster_version: builtins.str
    db_name: builtins.str
    elastic_ip: builtins.str
    encrypted: builtins.bool
    hsm_client_certificate_identifier: builtins.str
    hsm_configuration_identifier: builtins.str
    @property
    def iam_roles(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    kms_key_id: builtins.str
    @property
    def logging_properties(self) -> global___ClusterLoggingProperties: ...
    master_user_password: builtins.str
    master_username: builtins.str
    node_type: builtins.str
    number_of_nodes: builtins.int
    owner_account: builtins.str
    port: builtins.int
    preferred_maintenance_window: builtins.str
    publicly_accessible: builtins.bool
    snapshot_cluster_identifier: builtins.str
    snapshot_identifier: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def vpc_security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        allow_version_upgrade: builtins.bool = ...,
        automated_snapshot_retention_period: builtins.int = ...,
        availability_zone: builtins.str = ...,
        cluster_identifier: builtins.str = ...,
        cluster_parameter_group_name: builtins.str = ...,
        cluster_security_groups: collections.abc.Iterable[builtins.str] | None = ...,
        cluster_subnet_group_name: builtins.str = ...,
        cluster_type: builtins.str = ...,
        cluster_version: builtins.str = ...,
        db_name: builtins.str = ...,
        elastic_ip: builtins.str = ...,
        encrypted: builtins.bool = ...,
        hsm_client_certificate_identifier: builtins.str = ...,
        hsm_configuration_identifier: builtins.str = ...,
        iam_roles: collections.abc.Iterable[builtins.str] | None = ...,
        kms_key_id: builtins.str = ...,
        logging_properties: global___ClusterLoggingProperties | None = ...,
        master_user_password: builtins.str = ...,
        master_username: builtins.str = ...,
        node_type: builtins.str = ...,
        number_of_nodes: builtins.int = ...,
        owner_account: builtins.str = ...,
        port: builtins.int = ...,
        preferred_maintenance_window: builtins.str = ...,
        publicly_accessible: builtins.bool = ...,
        snapshot_cluster_identifier: builtins.str = ...,
        snapshot_identifier: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        vpc_security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["logging_properties", b"logging_properties", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_version_upgrade", b"allow_version_upgrade", "automated_snapshot_retention_period", b"automated_snapshot_retention_period", "availability_zone", b"availability_zone", "cluster_identifier", b"cluster_identifier", "cluster_parameter_group_name", b"cluster_parameter_group_name", "cluster_security_groups", b"cluster_security_groups", "cluster_subnet_group_name", b"cluster_subnet_group_name", "cluster_type", b"cluster_type", "cluster_version", b"cluster_version", "db_name", b"db_name", "elastic_ip", b"elastic_ip", "encrypted", b"encrypted", "hsm_client_certificate_identifier", b"hsm_client_certificate_identifier", "hsm_configuration_identifier", b"hsm_configuration_identifier", "iam_roles", b"iam_roles", "kms_key_id", b"kms_key_id", "logging_properties", b"logging_properties", "master_user_password", b"master_user_password", "master_username", b"master_username", "node_type", b"node_type", "number_of_nodes", b"number_of_nodes", "owner_account", b"owner_account", "port", b"port", "preferred_maintenance_window", b"preferred_maintenance_window", "publicly_accessible", b"publicly_accessible", "resource_info", b"resource_info", "snapshot_cluster_identifier", b"snapshot_cluster_identifier", "snapshot_identifier", b"snapshot_identifier", "tags", b"tags", "vpc_security_group_ids", b"vpc_security_group_ids"]) -> None: ...

global___Cluster = Cluster

@typing_extensions.final
class Redshift(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_FIELD_NUMBER: builtins.int
    CLUSTER_PARAMETER_GROUP_FIELD_NUMBER: builtins.int
    CLUSTER_SECURITY_GROUP_FIELD_NUMBER: builtins.int
    CLUSTER_SECURITY_GROUP_INGRESS_FIELD_NUMBER: builtins.int
    CLUSTER_SUBNET_GROUP_FIELD_NUMBER: builtins.int
    @property
    def cluster(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Cluster]: ...
    @property
    def cluster_parameter_group(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ClusterParameterGroup]: ...
    @property
    def cluster_security_group(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ClusterSecurityGroup]: ...
    @property
    def cluster_security_group_ingress(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ClusterSecurityGroupIngress]: ...
    @property
    def cluster_subnet_group(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ClusterSubnetGroup]: ...
    def __init__(
        self,
        *,
        cluster: collections.abc.Iterable[global___Cluster] | None = ...,
        cluster_parameter_group: collections.abc.Iterable[global___ClusterParameterGroup] | None = ...,
        cluster_security_group: collections.abc.Iterable[global___ClusterSecurityGroup] | None = ...,
        cluster_security_group_ingress: collections.abc.Iterable[global___ClusterSecurityGroupIngress] | None = ...,
        cluster_subnet_group: collections.abc.Iterable[global___ClusterSubnetGroup] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster", b"cluster", "cluster_parameter_group", b"cluster_parameter_group", "cluster_security_group", b"cluster_security_group", "cluster_security_group_ingress", b"cluster_security_group_ingress", "cluster_subnet_group", b"cluster_subnet_group"]) -> None: ...

global___Redshift = Redshift

@typing_extensions.final
class ClusterParameterGroupParameter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    PARAMETER_NAME_FIELD_NUMBER: builtins.int
    PARAMETER_VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    parameter_name: builtins.str
    parameter_value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        parameter_name: builtins.str = ...,
        parameter_value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["parameter_name", b"parameter_name", "parameter_value", b"parameter_value", "resource_info", b"resource_info"]) -> None: ...

global___ClusterParameterGroupParameter = ClusterParameterGroupParameter

@typing_extensions.final
class ClusterParameterGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    PARAMETER_GROUP_FAMILY_FIELD_NUMBER: builtins.int
    PARAMETERS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    parameter_group_family: builtins.str
    @property
    def parameters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ClusterParameterGroupParameter]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        parameter_group_family: builtins.str = ...,
        parameters: collections.abc.Iterable[global___ClusterParameterGroupParameter] | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "parameter_group_family", b"parameter_group_family", "parameters", b"parameters", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___ClusterParameterGroup = ClusterParameterGroup

@typing_extensions.final
class ClusterSecurityGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___ClusterSecurityGroup = ClusterSecurityGroup

@typing_extensions.final
class ClusterSecurityGroupIngress(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CIDR_IP_FIELD_NUMBER: builtins.int
    CLUSTER_SECURITY_GROUP_NAME_FIELD_NUMBER: builtins.int
    E_C2_SECURITY_GROUP_NAME_FIELD_NUMBER: builtins.int
    E_C2_SECURITY_GROUP_OWNER_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    cidr_ip: builtins.str
    cluster_security_group_name: builtins.str
    e_c2_security_group_name: builtins.str
    e_c2_security_group_owner_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        cidr_ip: builtins.str = ...,
        cluster_security_group_name: builtins.str = ...,
        e_c2_security_group_name: builtins.str = ...,
        e_c2_security_group_owner_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cidr_ip", b"cidr_ip", "cluster_security_group_name", b"cluster_security_group_name", "e_c2_security_group_name", b"e_c2_security_group_name", "e_c2_security_group_owner_id", b"e_c2_security_group_owner_id", "resource_info", b"resource_info"]) -> None: ...

global___ClusterSecurityGroupIngress = ClusterSecurityGroupIngress

@typing_extensions.final
class ClusterSubnetGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    SUBNET_IDS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    @property
    def subnet_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        subnet_ids: collections.abc.Iterable[builtins.str] | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "resource_info", b"resource_info", "subnet_ids", b"subnet_ids", "tags", b"tags"]) -> None: ...

global___ClusterSubnetGroup = ClusterSubnetGroup



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class AlarmDimension(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___AlarmDimension = AlarmDimension

@typing_extensions.final
class AlarmMetric(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DIMENSIONS_FIELD_NUMBER: builtins.int
    METRIC_NAME_FIELD_NUMBER: builtins.int
    NAMESPACE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def dimensions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AlarmDimension]: ...
    metric_name: builtins.str
    namespace: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        dimensions: collections.abc.Iterable[global___AlarmDimension] | None = ...,
        metric_name: builtins.str = ...,
        namespace: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dimensions", b"dimensions", "metric_name", b"metric_name", "namespace", b"namespace", "resource_info", b"resource_info"]) -> None: ...

global___AlarmMetric = AlarmMetric

@typing_extensions.final
class AlarmMetricStat(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    METRIC_FIELD_NUMBER: builtins.int
    PERIOD_FIELD_NUMBER: builtins.int
    STAT_FIELD_NUMBER: builtins.int
    UNIT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def metric(self) -> global___AlarmMetric: ...
    period: builtins.int
    stat: builtins.str
    unit: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        metric: global___AlarmMetric | None = ...,
        period: builtins.int = ...,
        stat: builtins.str = ...,
        unit: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metric", b"metric", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["metric", b"metric", "period", b"period", "resource_info", b"resource_info", "stat", b"stat", "unit", b"unit"]) -> None: ...

global___AlarmMetricStat = AlarmMetricStat

@typing_extensions.final
class AlarmMetricDataQuery(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    METRIC_STAT_FIELD_NUMBER: builtins.int
    PERIOD_FIELD_NUMBER: builtins.int
    RETURN_DATA_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    expression: builtins.str
    id: builtins.str
    label: builtins.str
    @property
    def metric_stat(self) -> global___AlarmMetricStat: ...
    period: builtins.int
    return_data: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        expression: builtins.str = ...,
        id: builtins.str = ...,
        label: builtins.str = ...,
        metric_stat: global___AlarmMetricStat | None = ...,
        period: builtins.int = ...,
        return_data: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metric_stat", b"metric_stat", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["expression", b"expression", "id", b"id", "label", b"label", "metric_stat", b"metric_stat", "period", b"period", "resource_info", b"resource_info", "return_data", b"return_data"]) -> None: ...

global___AlarmMetricDataQuery = AlarmMetricDataQuery

@typing_extensions.final
class Alarm(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ACTIONS_ENABLED_FIELD_NUMBER: builtins.int
    ALARM_ACTIONS_FIELD_NUMBER: builtins.int
    ALARM_DESCRIPTION_FIELD_NUMBER: builtins.int
    ALARM_NAME_FIELD_NUMBER: builtins.int
    COMPARISON_OPERATOR_FIELD_NUMBER: builtins.int
    DATAPOINTS_TO_ALARM_FIELD_NUMBER: builtins.int
    DIMENSIONS_FIELD_NUMBER: builtins.int
    EVALUATE_LOW_SAMPLE_COUNT_PERCENTILE_FIELD_NUMBER: builtins.int
    EVALUATION_PERIODS_FIELD_NUMBER: builtins.int
    EXTENDED_STATISTIC_FIELD_NUMBER: builtins.int
    INSUFFICIENT_DATA_ACTIONS_FIELD_NUMBER: builtins.int
    METRIC_NAME_FIELD_NUMBER: builtins.int
    METRICS_FIELD_NUMBER: builtins.int
    NAMESPACE_FIELD_NUMBER: builtins.int
    OK_ACTIONS_FIELD_NUMBER: builtins.int
    PERIOD_FIELD_NUMBER: builtins.int
    STATISTIC_FIELD_NUMBER: builtins.int
    THRESHOLD_FIELD_NUMBER: builtins.int
    THRESHOLD_METRIC_ID_FIELD_NUMBER: builtins.int
    TREAT_MISSING_DATA_FIELD_NUMBER: builtins.int
    UNIT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    actions_enabled: builtins.bool
    @property
    def alarm_actions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    alarm_description: builtins.str
    alarm_name: builtins.str
    comparison_operator: builtins.str
    datapoints_to_alarm: builtins.int
    @property
    def dimensions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AlarmDimension]: ...
    evaluate_low_sample_count_percentile: builtins.str
    evaluation_periods: builtins.int
    extended_statistic: builtins.str
    @property
    def insufficient_data_actions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    metric_name: builtins.str
    @property
    def metrics(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AlarmMetricDataQuery]: ...
    namespace: builtins.str
    @property
    def ok_actions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    period: builtins.int
    statistic: builtins.str
    threshold: builtins.float
    threshold_metric_id: builtins.str
    treat_missing_data: builtins.str
    unit: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        actions_enabled: builtins.bool = ...,
        alarm_actions: collections.abc.Iterable[builtins.str] | None = ...,
        alarm_description: builtins.str = ...,
        alarm_name: builtins.str = ...,
        comparison_operator: builtins.str = ...,
        datapoints_to_alarm: builtins.int = ...,
        dimensions: collections.abc.Iterable[global___AlarmDimension] | None = ...,
        evaluate_low_sample_count_percentile: builtins.str = ...,
        evaluation_periods: builtins.int = ...,
        extended_statistic: builtins.str = ...,
        insufficient_data_actions: collections.abc.Iterable[builtins.str] | None = ...,
        metric_name: builtins.str = ...,
        metrics: collections.abc.Iterable[global___AlarmMetricDataQuery] | None = ...,
        namespace: builtins.str = ...,
        ok_actions: collections.abc.Iterable[builtins.str] | None = ...,
        period: builtins.int = ...,
        statistic: builtins.str = ...,
        threshold: builtins.float = ...,
        threshold_metric_id: builtins.str = ...,
        treat_missing_data: builtins.str = ...,
        unit: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["actions_enabled", b"actions_enabled", "alarm_actions", b"alarm_actions", "alarm_description", b"alarm_description", "alarm_name", b"alarm_name", "comparison_operator", b"comparison_operator", "datapoints_to_alarm", b"datapoints_to_alarm", "dimensions", b"dimensions", "evaluate_low_sample_count_percentile", b"evaluate_low_sample_count_percentile", "evaluation_periods", b"evaluation_periods", "extended_statistic", b"extended_statistic", "insufficient_data_actions", b"insufficient_data_actions", "metric_name", b"metric_name", "metrics", b"metrics", "namespace", b"namespace", "ok_actions", b"ok_actions", "period", b"period", "resource_info", b"resource_info", "statistic", b"statistic", "threshold", b"threshold", "threshold_metric_id", b"threshold_metric_id", "treat_missing_data", b"treat_missing_data", "unit", b"unit"]) -> None: ...

global___Alarm = Alarm

@typing_extensions.final
class CloudWatch(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALARM_FIELD_NUMBER: builtins.int
    ANOMALY_DETECTOR_FIELD_NUMBER: builtins.int
    COMPOSITE_ALARM_FIELD_NUMBER: builtins.int
    DASHBOARD_FIELD_NUMBER: builtins.int
    INSIGHT_RULE_FIELD_NUMBER: builtins.int
    @property
    def alarm(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Alarm]: ...
    @property
    def anomaly_detector(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AnomalyDetector]: ...
    @property
    def composite_alarm(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CompositeAlarm]: ...
    @property
    def dashboard(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Dashboard]: ...
    @property
    def insight_rule(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___InsightRule]: ...
    def __init__(
        self,
        *,
        alarm: collections.abc.Iterable[global___Alarm] | None = ...,
        anomaly_detector: collections.abc.Iterable[global___AnomalyDetector] | None = ...,
        composite_alarm: collections.abc.Iterable[global___CompositeAlarm] | None = ...,
        dashboard: collections.abc.Iterable[global___Dashboard] | None = ...,
        insight_rule: collections.abc.Iterable[global___InsightRule] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["alarm", b"alarm", "anomaly_detector", b"anomaly_detector", "composite_alarm", b"composite_alarm", "dashboard", b"dashboard", "insight_rule", b"insight_rule"]) -> None: ...

global___CloudWatch = CloudWatch

@typing_extensions.final
class AnomalyDetectorRange(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    end_time: builtins.str
    start_time: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        end_time: builtins.str = ...,
        start_time: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["end_time", b"end_time", "resource_info", b"resource_info", "start_time", b"start_time"]) -> None: ...

global___AnomalyDetectorRange = AnomalyDetectorRange

@typing_extensions.final
class AnomalyDetectorConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    METRIC_TIME_ZONE_FIELD_NUMBER: builtins.int
    EXCLUDED_TIME_RANGES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    metric_time_zone: builtins.str
    @property
    def excluded_time_ranges(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AnomalyDetectorRange]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        metric_time_zone: builtins.str = ...,
        excluded_time_ranges: collections.abc.Iterable[global___AnomalyDetectorRange] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["excluded_time_ranges", b"excluded_time_ranges", "metric_time_zone", b"metric_time_zone", "resource_info", b"resource_info"]) -> None: ...

global___AnomalyDetectorConfiguration = AnomalyDetectorConfiguration

@typing_extensions.final
class AnomalyDetectorDimension(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    value: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        value: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___AnomalyDetectorDimension = AnomalyDetectorDimension

@typing_extensions.final
class AnomalyDetector(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    METRIC_NAME_FIELD_NUMBER: builtins.int
    STAT_FIELD_NUMBER: builtins.int
    CONFIGURATION_FIELD_NUMBER: builtins.int
    DIMENSIONS_FIELD_NUMBER: builtins.int
    NAMESPACE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    metric_name: builtins.str
    stat: builtins.str
    @property
    def configuration(self) -> global___AnomalyDetectorConfiguration: ...
    @property
    def dimensions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AnomalyDetectorDimension]: ...
    namespace: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        metric_name: builtins.str = ...,
        stat: builtins.str = ...,
        configuration: global___AnomalyDetectorConfiguration | None = ...,
        dimensions: collections.abc.Iterable[global___AnomalyDetectorDimension] | None = ...,
        namespace: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["configuration", b"configuration", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["configuration", b"configuration", "dimensions", b"dimensions", "metric_name", b"metric_name", "namespace", b"namespace", "resource_info", b"resource_info", "stat", b"stat"]) -> None: ...

global___AnomalyDetector = AnomalyDetector

@typing_extensions.final
class CompositeAlarm(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ALARM_NAME_FIELD_NUMBER: builtins.int
    ALARM_RULE_FIELD_NUMBER: builtins.int
    ALARM_DESCRIPTION_FIELD_NUMBER: builtins.int
    ACTIONS_ENABLED_FIELD_NUMBER: builtins.int
    OK_ACTIONS_FIELD_NUMBER: builtins.int
    ALARM_ACTIONS_FIELD_NUMBER: builtins.int
    INSUFFICIENT_DATA_ACTIONS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    alarm_name: builtins.str
    alarm_rule: builtins.str
    alarm_description: builtins.str
    actions_enabled: builtins.bool
    @property
    def ok_actions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def alarm_actions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def insufficient_data_actions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        alarm_name: builtins.str = ...,
        alarm_rule: builtins.str = ...,
        alarm_description: builtins.str = ...,
        actions_enabled: builtins.bool = ...,
        ok_actions: collections.abc.Iterable[builtins.str] | None = ...,
        alarm_actions: collections.abc.Iterable[builtins.str] | None = ...,
        insufficient_data_actions: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["actions_enabled", b"actions_enabled", "alarm_actions", b"alarm_actions", "alarm_description", b"alarm_description", "alarm_name", b"alarm_name", "alarm_rule", b"alarm_rule", "insufficient_data_actions", b"insufficient_data_actions", "ok_actions", b"ok_actions", "resource_info", b"resource_info"]) -> None: ...

global___CompositeAlarm = CompositeAlarm

@typing_extensions.final
class Dashboard(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DASHBOARD_NAME_FIELD_NUMBER: builtins.int
    DASHBOARD_BODY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    dashboard_name: builtins.str
    dashboard_body: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        dashboard_name: builtins.str = ...,
        dashboard_body: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dashboard_body", b"dashboard_body", "dashboard_name", b"dashboard_name", "resource_info", b"resource_info"]) -> None: ...

global___Dashboard = Dashboard

@typing_extensions.final
class InsightRuleTags(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> None: ...

global___InsightRuleTags = InsightRuleTags

@typing_extensions.final
class InsightRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RULE_STATE_FIELD_NUMBER: builtins.int
    RULE_BODY_FIELD_NUMBER: builtins.int
    RULE_NAME_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    rule_state: builtins.str
    rule_body: builtins.str
    rule_name: builtins.str
    @property
    def tags(self) -> global___InsightRuleTags: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        rule_state: builtins.str = ...,
        rule_body: builtins.str = ...,
        rule_name: builtins.str = ...,
        tags: global___InsightRuleTags | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "tags", b"tags"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "rule_body", b"rule_body", "rule_name", b"rule_name", "rule_state", b"rule_state", "tags", b"tags"]) -> None: ...

global___InsightRule = InsightRule



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_network_frontdoor.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-azure/azure_microsoft_network_frontdoor.proto\x12-oak9.tython.azure.microsoft_network_frontdoor\x1a\x13shared/shared.proto\"\xe6\x02\n\x1bMicrosoft_Network_FrontDoor\x12\x8c\x01\n,front_door_web_application_firewall_policies\x18\x01 \x03(\x0b\x32V.oak9.tython.azure.microsoft_network_frontdoor.FrontDoorWebApplicationFirewallPolicies\x12N\n\x0b\x66ront_doors\x18\x02 \x01(\x0b\x32\x39.oak9.tython.azure.microsoft_network_frontdoor.FrontDoors\x12h\n\x19\x66ront_doors_rules_engines\x18\x03 \x03(\x0b\x32\x45.oak9.tython.azure.microsoft_network_frontdoor.FrontDoorsRulesEngines\"\xac\x01\n\x15LoadBalancingSettings\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x16\n\x0eresource_state\x18\x03 \x01(\t\x12\'\n\x1f\x61\x64\x64itional_latency_milliseconds\x18\x04 \x01(\x05\x12\x13\n\x0bsample_size\x18\x05 \x01(\x05\x12#\n\x1bsuccessful_samples_required\x18\x06 \x01(\x05\"\xb8\x01\n\x13HealthProbeSettings\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x15\n\renabled_state\x18\x03 \x01(\t\x12\x1b\n\x13health_probe_method\x18\x04 \x01(\t\x12\x1b\n\x13interval_in_seconds\x18\x05 \x01(\x05\x12\x0c\n\x04path\x18\x06 \x01(\t\x12\x10\n\x08protocol\x18\x07 \x01(\t\x12\x16\n\x0eresource_state\x18\x08 \x01(\t\"\xb4\x04\n\'FrontDoorWebApplicationFirewallPolicies\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12S\n\x0c\x63ustom_rules\x18\x05 \x01(\x0b\x32=.oak9.tython.azure.microsoft_network_frontdoor.CustomRuleList\x12X\n\rmanaged_rules\x18\x06 \x01(\x0b\x32\x41.oak9.tython.azure.microsoft_network_frontdoor.ManagedRuleSetList\x12V\n\x0fpolicy_settings\x18\x07 \x01(\x0b\x32=.oak9.tython.azure.microsoft_network_frontdoor.PolicySettings\x12n\n\x04tags\x18\x08 \x03(\x0b\x32`.oak9.tython.azure.microsoft_network_frontdoor.FrontDoorWebApplicationFirewallPolicies.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9a\x01\n\x0ePolicySettings\x12\"\n\x1a\x63ustom_block_response_body\x18\x01 \x01(\t\x12)\n!custom_block_response_status_code\x18\x02 \x01(\x05\x12\x15\n\renabled_state\x18\x03 \x01(\t\x12\x0c\n\x04mode\x18\x04 \x01(\t\x12\x14\n\x0credirect_url\x18\x05 \x01(\t\"n\n\x12ManagedRuleSetList\x12X\n\x11managed_rule_sets\x18\x01 \x03(\x0b\x32=.oak9.tython.azure.microsoft_network_frontdoor.ManagedRuleSet\"\x9a\x02\n\x0eManagedRuleSet\x12W\n\nexclusions\x18\x01 \x03(\x0b\x32\x43.oak9.tython.azure.microsoft_network_frontdoor.ManagedRuleExclusion\x12\x65\n\x14rule_group_overrides\x18\x02 \x03(\x0b\x32G.oak9.tython.azure.microsoft_network_frontdoor.ManagedRuleGroupOverride\x12\x15\n\rrule_set_type\x18\x03 \x01(\t\x12\x18\n\x10rule_set_version\x18\x04 \x01(\t\x12\x17\n\x0frule_set_action\x18\x05 \x01(\t\"\xdf\x01\n\x18ManagedRuleGroupOverride\x12W\n\nexclusions\x18\x01 \x03(\x0b\x32\x43.oak9.tython.azure.microsoft_network_frontdoor.ManagedRuleExclusion\x12\x17\n\x0frule_group_name\x18\x02 \x01(\t\x12Q\n\x05rules\x18\x03 \x03(\x0b\x32\x42.oak9.tython.azure.microsoft_network_frontdoor.ManagedRuleOverride\"\xa6\x01\n\x13ManagedRuleOverride\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\t\x12\x15\n\renabled_state\x18\x02 \x01(\t\x12W\n\nexclusions\x18\x03 \x03(\x0b\x32\x43.oak9.tython.azure.microsoft_network_frontdoor.ManagedRuleExclusion\x12\x0f\n\x07rule_id\x18\x04 \x01(\t\"a\n\x14ManagedRuleExclusion\x12\x16\n\x0ematch_variable\x18\x01 \x01(\t\x12\x10\n\x08selector\x18\x02 \x01(\t\x12\x1f\n\x17selector_match_operator\x18\x03 \x01(\t\"Z\n\x0e\x43ustomRuleList\x12H\n\x05rules\x18\x01 \x03(\x0b\x32\x39.oak9.tython.azure.microsoft_network_frontdoor.CustomRule\"\x85\x02\n\nCustomRule\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\t\x12\x15\n\renabled_state\x18\x02 \x01(\t\x12W\n\x10match_conditions\x18\x03 \x03(\x0b\x32=.oak9.tython.azure.microsoft_network_frontdoor.MatchCondition\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x10\n\x08priority\x18\x05 \x01(\x05\x12&\n\x1erate_limit_duration_in_minutes\x18\x06 \x01(\x05\x12\x1c\n\x14rate_limit_threshold\x18\x07 \x01(\x05\x12\x11\n\trule_type\x18\x08 \x01(\t\"\x8f\x01\n\x0eMatchCondition\x12\x13\n\x0bmatch_value\x18\x01 \x03(\t\x12\x16\n\x0ematch_variable\x18\x02 \x01(\t\x12\x18\n\x10negate_condition\x18\x03 \x01(\x08\x12\x10\n\x08operator\x18\x04 \x01(\t\x12\x10\n\x08selector\x18\x05 \x01(\t\x12\x12\n\ntransforms\x18\x06 \x03(\t\"\xc6\x01\n\x16\x46rontDoorsRulesEngines\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x16\n\x0eresource_state\x18\x03 \x01(\t\x12M\n\x05rules\x18\x04 \x03(\x0b\x32>.oak9.tython.azure.microsoft_network_frontdoor.RulesEngineRule\"\x8a\x02\n\x0fRulesEngineRule\x12P\n\x06\x61\x63tion\x18\x01 \x01(\x0b\x32@.oak9.tython.azure.microsoft_network_frontdoor.RulesEngineAction\x12\x62\n\x10match_conditions\x18\x02 \x03(\x0b\x32H.oak9.tython.azure.microsoft_network_frontdoor.RulesEngineMatchCondition\x12!\n\x19match_processing_behavior\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x10\n\x08priority\x18\x05 \x01(\x05\"\xc1\x01\n\x19RulesEngineMatchCondition\x12\x18\n\x10negate_condition\x18\x01 \x01(\x08\x12 \n\x18rules_engine_match_value\x18\x02 \x03(\t\x12#\n\x1brules_engine_match_variable\x18\x03 \x01(\t\x12\x1d\n\x15rules_engine_operator\x18\x04 \x01(\t\x12\x10\n\x08selector\x18\x05 \x01(\t\x12\x12\n\ntransforms\x18\x06 \x03(\t\"\xb7\x02\n\x11RulesEngineAction\x12[\n\x16request_header_actions\x18\x01 \x03(\x0b\x32;.oak9.tython.azure.microsoft_network_frontdoor.HeaderAction\x12\\\n\x17response_header_actions\x18\x02 \x03(\x0b\x32;.oak9.tython.azure.microsoft_network_frontdoor.HeaderAction\x12g\n\x1croute_configuration_override\x18\x03 \x01(\x0b\x32\x41.oak9.tython.azure.microsoft_network_frontdoor.RouteConfiguration\"N\n\x0cHeaderAction\x12\x1a\n\x12header_action_type\x18\x01 \x01(\t\x12\x13\n\x0bheader_name\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xdd\x06\n\nFrontDoors\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12Q\n\rbackend_pools\x18\x04 \x03(\x0b\x32:.oak9.tython.azure.microsoft_network_frontdoor.BackendPool\x12\x63\n\x16\x62\x61\x63kend_pools_settings\x18\x05 \x01(\x0b\x32\x43.oak9.tython.azure.microsoft_network_frontdoor.BackendPoolsSettings\x12\x15\n\renabled_state\x18\x06 \x01(\t\x12\x15\n\rfriendly_name\x18\x07 \x01(\t\x12[\n\x12\x66rontend_endpoints\x18\x08 \x03(\x0b\x32?.oak9.tython.azure.microsoft_network_frontdoor.FrontendEndpoint\x12\x61\n\x15health_probe_settings\x18\t \x03(\x0b\x32\x42.oak9.tython.azure.microsoft_network_frontdoor.HealthProbeSettings\x12\x65\n\x17load_balancing_settings\x18\n \x03(\x0b\x32\x44.oak9.tython.azure.microsoft_network_frontdoor.LoadBalancingSettings\x12\x16\n\x0eresource_state\x18\x0b \x01(\t\x12Q\n\rrouting_rules\x18\x0c \x03(\x0b\x32:.oak9.tython.azure.microsoft_network_frontdoor.RoutingRule\x12Q\n\x04tags\x18\r \x03(\x0b\x32\x43.oak9.tython.azure.microsoft_network_frontdoor.FrontDoors.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xfb\x03\n\x0bRoutingRule\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x15\n\renabled_state\x18\x03 \x01(\t\x12\x19\n\x11patterns_to_match\x18\x04 \x03(\t\x12\x16\n\x0eresource_state\x18\x05 \x01(\t\x12^\n\x13route_configuration\x18\x06 \x01(\x0b\x32\x41.oak9.tython.azure.microsoft_network_frontdoor.RouteConfiguration\x12\x14\n\x0crules_engine\x18\x07 \x01(\t\x12\x98\x01\n$web_application_firewall_policy_link\x18\x08 \x01(\x0b\x32j.oak9.tython.azure.microsoft_network_frontdoor.RoutingRuleUpdateParametersWebApplicationFirewallPolicyLink\x12[\n\x12\x66rontend_endpoints\x18\t \x03(\x0b\x32?.oak9.tython.azure.microsoft_network_frontdoor.FrontendEndpoint\x12\x1a\n\x12\x61\x63\x63\x65pted_protocols\x18\n \x01(\t\"I\n;RoutingRuleUpdateParametersWebApplicationFirewallPolicyLink\x12\n\n\x02id\x18\x01 \x01(\t\"\"\n\x12RouteConfiguration\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xc5\x02\n\x10\x46rontendEndpoint\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\thost_name\x18\x03 \x01(\t\x12\x16\n\x0eresource_state\x18\x04 \x01(\t\x12&\n\x1esession_affinity_enabled_state\x18\x05 \x01(\t\x12$\n\x1csession_affinity_ttl_seconds\x18\x06 \x01(\x05\x12\x9d\x01\n$web_application_firewall_policy_link\x18\x07 \x01(\x0b\x32o.oak9.tython.azure.microsoft_network_frontdoor.FrontendEndpointUpdateParametersWebApplicationFirewallPolicyLink\"N\n@FrontendEndpointUpdateParametersWebApplicationFirewallPolicyLink\x12\n\n\x02id\x18\x01 \x01(\t\"a\n\x14\x42\x61\x63kendPoolsSettings\x12&\n\x1e\x65nforce_certificate_name_check\x18\x01 \x01(\t\x12!\n\x19send_recv_timeout_seconds\x18\x02 \x01(\x05\"\xd3\x02\n\x0b\x42\x61\x63kendPool\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12H\n\x08\x62\x61\x63kends\x18\x03 \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_network_frontdoor.Backend\x12\x61\n\x15health_probe_settings\x18\x04 \x01(\x0b\x32\x42.oak9.tython.azure.microsoft_network_frontdoor.HealthProbeSettings\x12\x65\n\x17load_balancing_settings\x18\x05 \x01(\x0b\x32\x44.oak9.tython.azure.microsoft_network_frontdoor.LoadBalancingSettings\x12\x16\n\x0eresource_state\x18\x06 \x01(\t\"\xda\x01\n\x07\x42\x61\x63kend\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x1b\n\x13\x62\x61\x63kend_host_header\x18\x02 \x01(\t\x12\x15\n\renabled_state\x18\x03 \x01(\t\x12\x11\n\thttp_port\x18\x04 \x01(\x05\x12\x12\n\nhttps_port\x18\x05 \x01(\x05\x12\x10\n\x08priority\x18\x06 \x01(\x05\x12\x1a\n\x12private_link_alias\x18\x07 \x01(\t\x12%\n\x1dprivate_link_approval_message\x18\x08 \x01(\t\x12\x0e\n\x06weight\x18\t \x01(\x05\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_network_frontdoor_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _FRONTDOORWEBAPPLICATIONFIREWALLPOLICIES_TAGSENTRY._options = None
  _FRONTDOORWEBAPPLICATIONFIREWALLPOLICIES_TAGSENTRY._serialized_options = b'8\001'
  _FRONTDOORS_TAGSENTRY._options = None
  _FRONTDOORS_TAGSENTRY._serialized_options = b'8\001'
  _MICROSOFT_NETWORK_FRONTDOOR._serialized_start=118
  _MICROSOFT_NETWORK_FRONTDOOR._serialized_end=476
  _LOADBALANCINGSETTINGS._serialized_start=479
  _LOADBALANCINGSETTINGS._serialized_end=651
  _HEALTHPROBESETTINGS._serialized_start=654
  _HEALTHPROBESETTINGS._serialized_end=838
  _FRONTDOORWEBAPPLICATIONFIREWALLPOLICIES._serialized_start=841
  _FRONTDOORWEBAPPLICATIONFIREWALLPOLICIES._serialized_end=1405
  _FRONTDOORWEBAPPLICATIONFIREWALLPOLICIES_TAGSENTRY._serialized_start=1362
  _FRONTDOORWEBAPPLICATIONFIREWALLPOLICIES_TAGSENTRY._serialized_end=1405
  _POLICYSETTINGS._serialized_start=1408
  _POLICYSETTINGS._serialized_end=1562
  _MANAGEDRULESETLIST._serialized_start=1564
  _MANAGEDRULESETLIST._serialized_end=1674
  _MANAGEDRULESET._serialized_start=1677
  _MANAGEDRULESET._serialized_end=1959
  _MANAGEDRULEGROUPOVERRIDE._serialized_start=1962
  _MANAGEDRULEGROUPOVERRIDE._serialized_end=2185
  _MANAGEDRULEOVERRIDE._serialized_start=2188
  _MANAGEDRULEOVERRIDE._serialized_end=2354
  _MANAGEDRULEEXCLUSION._serialized_start=2356
  _MANAGEDRULEEXCLUSION._serialized_end=2453
  _CUSTOMRULELIST._serialized_start=2455
  _CUSTOMRULELIST._serialized_end=2545
  _CUSTOMRULE._serialized_start=2548
  _CUSTOMRULE._serialized_end=2809
  _MATCHCONDITION._serialized_start=2812
  _MATCHCONDITION._serialized_end=2955
  _FRONTDOORSRULESENGINES._serialized_start=2958
  _FRONTDOORSRULESENGINES._serialized_end=3156
  _RULESENGINERULE._serialized_start=3159
  _RULESENGINERULE._serialized_end=3425
  _RULESENGINEMATCHCONDITION._serialized_start=3428
  _RULESENGINEMATCHCONDITION._serialized_end=3621
  _RULESENGINEACTION._serialized_start=3624
  _RULESENGINEACTION._serialized_end=3935
  _HEADERACTION._serialized_start=3937
  _HEADERACTION._serialized_end=4015
  _FRONTDOORS._serialized_start=4018
  _FRONTDOORS._serialized_end=4879
  _FRONTDOORS_TAGSENTRY._serialized_start=1362
  _FRONTDOORS_TAGSENTRY._serialized_end=1405
  _ROUTINGRULE._serialized_start=4882
  _ROUTINGRULE._serialized_end=5389
  _ROUTINGRULEUPDATEPARAMETERSWEBAPPLICATIONFIREWALLPOLICYLINK._serialized_start=5391
  _ROUTINGRULEUPDATEPARAMETERSWEBAPPLICATIONFIREWALLPOLICYLINK._serialized_end=5464
  _ROUTECONFIGURATION._serialized_start=5466
  _ROUTECONFIGURATION._serialized_end=5500
  _FRONTENDENDPOINT._serialized_start=5503
  _FRONTENDENDPOINT._serialized_end=5828
  _FRONTENDENDPOINTUPDATEPARAMETERSWEBAPPLICATIONFIREWALLPOLICYLINK._serialized_start=5830
  _FRONTENDENDPOINTUPDATEPARAMETERSWEBAPPLICATIONFIREWALLPOLICYLINK._serialized_end=5908
  _BACKENDPOOLSSETTINGS._serialized_start=5910
  _BACKENDPOOLSSETTINGS._serialized_end=6007
  _BACKENDPOOL._serialized_start=6010
  _BACKENDPOOL._serialized_end=6349
  _BACKEND._serialized_start=6352
  _BACKEND._serialized_end=6570
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_cloudformation.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x61ws/aws_cloudformation.proto\x12\x1eoak9.tython.aws.cloudformation\x1a\x13shared/shared.proto\"`\n\x0e\x43ustomResource\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rservice_token\x18\x02 \x01(\t\"\x9d\x03\n\x0e\x43loudFormation\x12G\n\x0f\x63ustom_resource\x18\x01 \x03(\x0b\x32..oak9.tython.aws.cloudformation.CustomResource\x12\x34\n\x05macro\x18\x02 \x03(\x0b\x32%.oak9.tython.aws.cloudformation.Macro\x12\x34\n\x05stack\x18\x03 \x03(\x0b\x32%.oak9.tython.aws.cloudformation.Stack\x12;\n\tstack_set\x18\x04 \x03(\x0b\x32(.oak9.tython.aws.cloudformation.StackSet\x12\x45\n\x0ewait_condition\x18\x05 \x03(\x0b\x32-.oak9.tython.aws.cloudformation.WaitCondition\x12R\n\x15wait_condition_handle\x18\x06 \x03(\x0b\x32\x33.oak9.tython.aws.cloudformation.WaitConditionHandle\"\xa8\x01\n\x05Macro\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x15\n\rfunction_name\x18\x03 \x01(\t\x12\x16\n\x0elog_group_name\x18\x04 \x01(\t\x12\x14\n\x0clog_role_arn\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\"\xf9\x02\n\x05Stack\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11notification_arns\x18\x02 \x03(\t\x12I\n\nparameters\x18\x03 \x03(\x0b\x32\x35.oak9.tython.aws.cloudformation.Stack.ParametersEntry\x12=\n\x04tags\x18\x04 \x03(\x0b\x32/.oak9.tython.aws.cloudformation.Stack.TagsEntry\x12\x16\n\x0etemplate_u_r_l\x18\x05 \x01(\t\x12\x1a\n\x12timeout_in_minutes\x18\x06 \x01(\x05\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8c\x01\n\x16StackSetAutoDeployment\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12(\n retain_stacks_on_account_removal\x18\x03 \x01(\x08\"\xf5\x01\n\x1cStackSetOperationPreferences\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1f\n\x17\x66\x61ilure_tolerance_count\x18\x02 \x01(\x05\x12$\n\x1c\x66\x61ilure_tolerance_percentage\x18\x03 \x01(\x05\x12\x1c\n\x14max_concurrent_count\x18\x04 \x01(\x05\x12!\n\x19max_concurrent_percentage\x18\x05 \x01(\x05\x12\x14\n\x0cregion_order\x18\x06 \x03(\t\"\x87\x01\n\x19StackSetDeploymentTargets\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08\x61\x63\x63ounts\x18\x02 \x03(\t\x12\x1f\n\x17organizational_unit_ids\x18\x03 \x03(\t\"|\n\x11StackSetParameter\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rparameter_key\x18\x02 \x01(\t\x12\x17\n\x0fparameter_value\x18\x03 \x01(\t\"\x89\x02\n\x16StackSetStackInstances\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12U\n\x12\x64\x65ployment_targets\x18\x02 \x01(\x0b\x32\x39.oak9.tython.aws.cloudformation.StackSetDeploymentTargets\x12\x0f\n\x07regions\x18\x03 \x03(\t\x12N\n\x13parameter_overrides\x18\x04 \x03(\x0b\x32\x31.oak9.tython.aws.cloudformation.StackSetParameter\"\xc8\x05\n\x08StackSet\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0estack_set_name\x18\x02 \x01(\t\x12\x1f\n\x17\x61\x64ministration_role_arn\x18\x03 \x01(\t\x12O\n\x0f\x61uto_deployment\x18\x04 \x01(\x0b\x32\x36.oak9.tython.aws.cloudformation.StackSetAutoDeployment\x12\x14\n\x0c\x63\x61pabilities\x18\x05 \x03(\t\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12\x1b\n\x13\x65xecution_role_name\x18\x07 \x01(\t\x12[\n\x15operation_preferences\x18\x08 \x01(\x0b\x32<.oak9.tython.aws.cloudformation.StackSetOperationPreferences\x12U\n\x15stack_instances_group\x18\t \x03(\x0b\x32\x36.oak9.tython.aws.cloudformation.StackSetStackInstances\x12\x45\n\nparameters\x18\n \x03(\x0b\x32\x31.oak9.tython.aws.cloudformation.StackSetParameter\x12\x18\n\x10permission_model\x18\x0b \x01(\t\x12@\n\x04tags\x18\x0c \x03(\x0b\x32\x32.oak9.tython.aws.cloudformation.StackSet.TagsEntry\x12\x15\n\rtemplate_body\x18\r \x01(\t\x12\x16\n\x0etemplate_u_r_l\x18\x0e \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"x\n\rWaitCondition\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05\x63ount\x18\x02 \x01(\x05\x12\x0e\n\x06handle\x18\x03 \x01(\t\x12\x0f\n\x07timeout\x18\x04 \x01(\t\"N\n\x13WaitConditionHandle\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_cloudformation_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _STACK_PARAMETERSENTRY._options = None
  _STACK_PARAMETERSENTRY._serialized_options = b'8\001'
  _STACK_TAGSENTRY._options = None
  _STACK_TAGSENTRY._serialized_options = b'8\001'
  _STACKSET_TAGSENTRY._options = None
  _STACKSET_TAGSENTRY._serialized_options = b'8\001'
  _CUSTOMRESOURCE._serialized_start=85
  _CUSTOMRESOURCE._serialized_end=181
  _CLOUDFORMATION._serialized_start=184
  _CLOUDFORMATION._serialized_end=597
  _MACRO._serialized_start=600
  _MACRO._serialized_end=768
  _STACK._serialized_start=771
  _STACK._serialized_end=1148
  _STACK_PARAMETERSENTRY._serialized_start=1054
  _STACK_PARAMETERSENTRY._serialized_end=1103
  _STACK_TAGSENTRY._serialized_start=1105
  _STACK_TAGSENTRY._serialized_end=1148
  _STACKSETAUTODEPLOYMENT._serialized_start=1151
  _STACKSETAUTODEPLOYMENT._serialized_end=1291
  _STACKSETOPERATIONPREFERENCES._serialized_start=1294
  _STACKSETOPERATIONPREFERENCES._serialized_end=1539
  _STACKSETDEPLOYMENTTARGETS._serialized_start=1542
  _STACKSETDEPLOYMENTTARGETS._serialized_end=1677
  _STACKSETPARAMETER._serialized_start=1679
  _STACKSETPARAMETER._serialized_end=1803
  _STACKSETSTACKINSTANCES._serialized_start=1806
  _STACKSETSTACKINSTANCES._serialized_end=2071
  _STACKSET._serialized_start=2074
  _STACKSET._serialized_end=2786
  _STACKSET_TAGSENTRY._serialized_start=1105
  _STACKSET_TAGSENTRY._serialized_end=1148
  _WAITCONDITION._serialized_start=2788
  _WAITCONDITION._serialized_end=2908
  _WAITCONDITIONHANDLE._serialized_start=2910
  _WAITCONDITIONHANDLE._serialized_end=2988
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class AssuredWorkloadsWorkloadXKmsSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NEXT_ROTATION_TIME_FIELD_NUMBER: builtins.int
    ROTATION_PERIOD_FIELD_NUMBER: builtins.int
    next_rotation_time: builtins.str
    rotation_period: builtins.str
    def __init__(
        self,
        *,
        next_rotation_time: builtins.str = ...,
        rotation_period: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["next_rotation_time", b"next_rotation_time", "rotation_period", b"rotation_period"]) -> None: ...

global___AssuredWorkloadsWorkloadXKmsSettings = AssuredWorkloadsWorkloadXKmsSettings

@typing_extensions.final
class AssuredWorkloadsWorkloadXResourceSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_ID_FIELD_NUMBER: builtins.int
    RESOURCE_TYPE_FIELD_NUMBER: builtins.int
    resource_id: builtins.str
    resource_type: builtins.str
    def __init__(
        self,
        *,
        resource_id: builtins.str = ...,
        resource_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_id", b"resource_id", "resource_type", b"resource_type"]) -> None: ...

global___AssuredWorkloadsWorkloadXResourceSettings = AssuredWorkloadsWorkloadXResourceSettings

@typing_extensions.final
class AssuredWorkloadsWorkloadXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___AssuredWorkloadsWorkloadXTimeouts = AssuredWorkloadsWorkloadXTimeouts

@typing_extensions.final
class AssuredWorkloadsWorkload(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class ResourcesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    BILLING_ACCOUNT_FIELD_NUMBER: builtins.int
    COMPLIANCE_REGIME_FIELD_NUMBER: builtins.int
    CREATE_TIME_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ORGANIZATION_FIELD_NUMBER: builtins.int
    PROVISIONED_RESOURCES_PARENT_FIELD_NUMBER: builtins.int
    RESOURCES_FIELD_NUMBER: builtins.int
    KMS_SETTINGS_FIELD_NUMBER: builtins.int
    RESOURCE_SETTINGS_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    billing_account: builtins.str
    compliance_regime: builtins.str
    create_time: builtins.str
    display_name: builtins.str
    id: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    location: builtins.str
    name: builtins.str
    organization: builtins.str
    provisioned_resources_parent: builtins.str
    @property
    def resources(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def kms_settings(self) -> global___AssuredWorkloadsWorkloadXKmsSettings: ...
    @property
    def resource_settings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AssuredWorkloadsWorkloadXResourceSettings]: ...
    @property
    def timeouts(self) -> global___AssuredWorkloadsWorkloadXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        billing_account: builtins.str = ...,
        compliance_regime: builtins.str = ...,
        create_time: builtins.str = ...,
        display_name: builtins.str = ...,
        id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        organization: builtins.str = ...,
        provisioned_resources_parent: builtins.str = ...,
        resources: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        kms_settings: global___AssuredWorkloadsWorkloadXKmsSettings | None = ...,
        resource_settings: collections.abc.Iterable[global___AssuredWorkloadsWorkloadXResourceSettings] | None = ...,
        timeouts: global___AssuredWorkloadsWorkloadXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["kms_settings", b"kms_settings", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["billing_account", b"billing_account", "compliance_regime", b"compliance_regime", "create_time", b"create_time", "display_name", b"display_name", "id", b"id", "kms_settings", b"kms_settings", "labels", b"labels", "location", b"location", "name", b"name", "organization", b"organization", "provisioned_resources_parent", b"provisioned_resources_parent", "resource_info", b"resource_info", "resource_settings", b"resource_settings", "resources", b"resources", "timeouts", b"timeouts"]) -> None: ...

global___AssuredWorkloadsWorkload = AssuredWorkloadsWorkload



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ComputeSharedVpcHostProjectXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___ComputeSharedVpcHostProjectXTimeouts = ComputeSharedVpcHostProjectXTimeouts

@typing_extensions.final
class ComputeSharedVpcHostProject(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    id: builtins.str
    project: builtins.str
    @property
    def timeouts(self) -> global___ComputeSharedVpcHostProjectXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        project: builtins.str = ...,
        timeouts: global___ComputeSharedVpcHostProjectXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "project", b"project", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___ComputeSharedVpcHostProject = ComputeSharedVpcHostProject

@typing_extensions.final
class ComputeSharedVpcServiceProjectXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___ComputeSharedVpcServiceProjectXTimeouts = ComputeSharedVpcServiceProjectXTimeouts

@typing_extensions.final
class ComputeSharedVpcServiceProject(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_PROJECT_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    SERVICE_PROJECT_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    host_project: builtins.str
    id: builtins.str
    service_project: builtins.str
    @property
    def timeouts(self) -> global___ComputeSharedVpcServiceProjectXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        host_project: builtins.str = ...,
        id: builtins.str = ...,
        service_project: builtins.str = ...,
        timeouts: global___ComputeSharedVpcServiceProjectXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["host_project", b"host_project", "id", b"id", "resource_info", b"resource_info", "service_project", b"service_project", "timeouts", b"timeouts"]) -> None: ...

global___ComputeSharedVpcServiceProject = ComputeSharedVpcServiceProject



from os import PathLike
from typing import Union
from git import Repo, exc


def sync_remote_repo_to_local(repo_url: Union[str, PathLike], local_path: Union[str, PathLike]) -> None:
    """
    When the supplied local_path is an empty directory, this function will clone the repo
    identified by the repo_url.
    When the local_path is a non-empty directory, the function attempts to pull the changes to
    the local repo.
    param repo_url: URL of the GitHub repository
    param local_path: Local path (must exist) where to clone or pull the code
    """
    try:
        repo = Repo(local_path)
        # TODO: If we accidentally modified vendor's repos, we would need to do a hard reset.
        # See https://stackoverflow.com/questions/1125968/how-do-i-force-git-pull-to-overwrite-local-files
        repo.remotes.origin.pull()
    except exc.InvalidGitRepositoryError:
        # Assuming that the program runs for the fist time - attempting to clone.
        Repo.clone_from(repo_url, local_path)
